@@ -1,5 +1,4 @@
 context("Package")
-
 test_that("package data", {
   expect_equal(dim(hacker), c(236, 4))
   expect_equal(class(hacker)[1], "ngram")
@@ -14,19 +13,13 @@ test_that("utility functions", {
 })
 
 context("Google")
-
-# Download some ngrams
-ng_hacker <- ngram(c("hacker", "programmer"),
-                  corpus = c("en-2012", "en-US-2012"),
-                  year_start = 1950, year_end = 2008)
-ng_dog_i <- ngrami("dog", year_start = 1950, year_end = 2020)
-ng_military <- ngram(c("military"), corpus = "en-2012",
-            year_start = 1940, year_end = 2005,
-            smoothing = 0, count = TRUE)
-
 test_that("google calls", {
-  expect_equal(dim(ng_dog_i), c(70, 4))
-  expect_equal(dim(ng_hacker), dim(hacker))
+  skip_if_offline()
+  expect_equal(dim( ngrami("dog", year_start = 1950, year_end = 2020)), c(70, 4))
+  expect_equal(dim(ngram(c("hacker", "programmer"), corpus = c("en-2012", "en-US-2012"), 
+                         year_start = 1950, year_end = 2008)), dim(hacker))
   expect_equal(dim(ngramw(hacker)), c(118, 4))
-  expect_equal(dim(ng_military), c(66, 5))
+  expect_equal(dim(ngram(c("military"), corpus = "en-2012", year_start = 1940, 
+                         year_end = 2005, smoothing = 0, count = TRUE)), c(66, 5))
 })
+
